Struct autocxx_parser::IncludeCppConfig [−][src]
pub struct IncludeCppConfig {
pub inclusions: Vec<String>,
pub unsafe_policy: UnsafePolicy,
pub parse_only: bool,
pub exclude_impls: bool,
pub rust_types: Vec<Ident>,
pub subclasses: Vec<Subclass>,
// some fields omitted
}Fields
inclusions: Vec<String>unsafe_policy: UnsafePolicyparse_only: boolexclude_impls: boolrust_types: Vec<Ident>subclasses: Vec<Subclass>Implementations
Whether to avoid generating the standard helpful utility functions which we normally include in every mod.
Items which the user has explicitly asked us to generate; we should raise an error if we weren’t able to do so.
The allowlist of items to be passed into bindgen, if any.
Whether this type is on the allowlist specified by the user.
A note on the allowlist handling in general. It’s used in two places:
- As directives to bindgen
- After bindgen has generated code, to filter the APIs which we pass to cxx. This second pass may seem redundant. But sometimes bindgen generates unnecessary stuff.